local L = AceLibrary("AceLocale-2.2"):new("Automaton_Whine")
Automaton_Whine = Automaton:NewModule("Whine", "AceEvent-2.0", "AceConsole-2.0", "AceDebug-2.0")

L:RegisterTranslations("enUS", function() return {
	["Whine"] = true,
	["Options for spamming emotes about low health or mana."] = true,
	["Enabled"] = true,
	["Complain about being low health or mana with an annoying emote."] = true,
	["HP"] = true,
	["Threshold for how soon to beg for healing"] = true,
	["Mana"] = true,
	["Threshold for how soon to complain about mana"] = true,
	["About"] = true,
	["Choose what to whine about"] = true,
} end)

L:RegisterTranslations("koKR", function() return {
	["Whine"] = "감정 표현",
	["Options for spamming emotes about low health or mana."] = "낮은 체력이나 마나에 대해 감정 표현을 알림니다.",
	["Enabled"] = "활성화",
	["Complain about being low health or mana with an annoying emote."] = "낮은 체력이나 마나시 감정 표현을 합니다.",
	["HP"] = "체력",
	["Threshold for how soon to beg for healing"] = "감정 표현을 할 체력값을 설정합니다.",
	["Mana"] = "마나",
	["Threshold for how soon to complain about mana"] = "감정 표현을 할 마나값을 설정합니다.",
	["About"] = "정보",
	["Choose what to whine about"] = "무엇을 감정 표현으로 말할지를 선택합니다.",
} end)

Automaton:RegisterDefaults('profile', {
	whineHP = 15,
	whineMana = 5,
	whineAbout = "both"
})

Automaton.options.args.whine = {
	type = 'group',
	name = L["Whine"],
	desc = L["Options for spamming emotes about low health or mana."],
	args = {
		toggle = {
			type = 'toggle',
			name = L["Enabled"],
			desc = L["Complain about being low health or mana with an annoying emote."],
			get = function() return Automaton:IsModuleActive("Whine") end,
			set = function(v) Automaton:ToggleModuleActive("Whine", v) end,
		},
		hp = {
			type = 'range',
			name = L["HP"],
			desc = L["Threshold for how soon to beg for healing"],
			usage = '(5-35)',
			min = 5,
			max = 35,
			step = 1,
			get = function() return Automaton.db.profile.whineHP end,
			set = function(v) Automaton.db.profile.whineHP = v end,
		},
		mana = {
			type = 'range',
			name = L["Mana"],
			desc = L["Threshold for how soon to complain about mana"],
			usage = '(5-35)',
			min = 5,
			max = 35,
			step = 1,
			get = function() return Automaton.db.profile.whineMana end,
			set = function(v) Automaton.db.profile.whineMana = v end,
		},
		about = {
			type = 'text',
			name = L["About"],
			desc = L["Choose what to whine about"],
			get = function() return Automaton.db.profile.whineAbout end,
			set = function(v) Automaton_Whine:SetEvents(v) end,
			validate = {"hp","mana","both"},
		}
	}
}

local hpwatch = true
local manawatch = true

function Automaton_Whine:OnEnable()
	self:SetEvents(Automaton.db.profile.whineAbout)
end

function Automaton_Whine:SetEvents(about)
	Automaton.db.profile.whineAbout = about

	if about == "hp" then
		self:RegisterEvent("UNIT_HEALTH")
		if self:IsEventRegistered("UNIT_MANA") then
			self:UnregisterEvent("UNIT_MANA")
		end
	elseif about == "mana" then
		if UnitPowerType("player") == 0 then
			self:RegisterEvent("UNIT_MANA")
		end
		if self:IsEventRegistered("UNIT_HEALTH") then
			self:UnregisterEvent("UNIT_HEALTH")
		end
	else
		self:RegisterEvent("UNIT_HEALTH")
		if UnitPowerType("player") == 0 then
			self:RegisterEvent("UNIT_MANA")
		end
	end
end

function Automaton_Whine:UNIT_HEALTH(unit)
	if not unit == "player" then return end
	local percent = (UnitHealth("player") / UnitHealthMax("player")) * 100
	self:Debug("Waaaaaaah!! My health is at "..percent)
	if hpwatch and percent < Automaton.db.profile.whineHP then
		hpwatch = false
		DoEmote("healme")
	elseif not hpwatch and percent > Automaton.db.profile.whineHP then
		hpwatch = true
	end
end

function Automaton_Whine:UNIT_MANA(unit)
	if not unit == "player" then return end
	local percent = (UnitMana("player") / UnitManaMax("player")) * 100
	self:Debug("Waaaaaaah!! My mana is at "..percent)
	if manawatch and percent < Automaton.db.profile.whineMana then
		manawatch = false
		DoEmote("oom")
	elseif not manawatch and percent > Automaton.db.profile.whineMana then
		manawatch = true
	end
end